@@ -28,10 +28,8 @@
 
 #ifdef HAVE_GNUTLS
 #include <gnutls/gnutls.h>
-#ifdef HAVE_GNUTLS_SOCKET_H
 #include <gnutls/socket.h>
 #endif
-#endif
 
 #include "internal.h"
 #include "nbdkit-string.h"
@@ -532,13 +530,6 @@ set_up_certificate_credentials (struct nbd_handle *h,
   return NULL;
 
  found_certificates:
-#ifdef HAVE_GNUTLS_SESSION_SET_VERIFY_CERT
-  if (h->hostname && h->tls_verify_peer)
-    gnutls_session_set_verify_cert (session, h->hostname, 0);
-#else
-  debug (h, "ignoring nbd_set_tls_verify_peer, this requires GnuTLS >= 3.4.6");
-#endif
-
   err = gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, ret);
   if (err < 0) {
     set_error (0, "gnutls_credentials_set: %s", gnutls_strerror (err));
@@ -653,6 +644,9 @@ nbd_internal_crypto_create_session (struct nbd_handle *h,
       gnutls_deinit (session);
       return NULL;
     }
+
+    if (h->tls_verify_peer)
+      gnutls_session_set_verify_cert (session, h->hostname, 0);
   }
 
   /* Wrap the underlying socket with GnuTLS. */
